@@ -3,11 +3,10 @@
 # SPDX-License-Identifier: MIT
 
 import time
-import busio
 import board
 import adafruit_sht4x
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()
 sht = adafruit_sht4x.SHT4x(i2c)
 print("Found SHT4x with serial number", hex(sht.serial_number))
 
